      // AmpelModel.java                              MM 2007
// MVC-Model                                    AZ 2006

import java.awt.*;                             // Color
import Tools.MVC.*;                       // SuperModel

/**
 * Simulation einer Ampelschaltung
 * unter Verwendung des MVC-Tool.
 */
public class AmpelModel
  extends SuperModel
{
                                            // coreData
/**
 * Ampelzustand, Startfarbe ist gelb, 2. Licht.
 */
  private boolean[] light = { false, true, false};

/* ------------------------------------------------- */
                                    // getData-Methoden
/**
 * Lesen eines Ampellichtes.
 * @param number Nummer des Ampellichtes
 *		( 0 .. oben, 1 .. mitte, 2 .. unten)
 * @return Ampellichtzustand (true .. eingeschalten)
 */
  public boolean getLight( int number)
  {
    try
    {
      return light[ number];
    }
    catch(IndexOutOfBoundsException e)
    {
      return false;
    }
  }

/**
 * Lesen des Ampelzustandes, benutzt Serverprotokoll.
 * @return Ampelzustand (true .. Licht eingeschalten)
 */
  public boolean[] getLight()
  {
      return light;
  }

/* ------------------------------------------------- */
                                    // service-Methoden
/**
 * Schalten der Ampel.
 */
  public void setLight()
  {                            // Ampel wird geschaltet
    for( int number = 0; number < 3; number++)
      if( light[ number])
      {
        light[ number] = false;
        light[ ( number + 1) % 3] = true;
        break;
      }

    setChanged();               // Aenderungen anzeigen
    notifyObservers( light);
  }

/**
 * Setzen der Ampel, benutzt Clientprotokoll.
 * @param l Ampelzustand (true .. Licht eingeschalten)
 */
  public void setLight( boolean[] l)
  {
    if( l.length < 3) return;
                                   // Ampel wird gesetzt
    for( int number = 0; number < 3; number++)
      light[ number] = l[ number];

    setChanged();               // Aenderungen anzeigen
    notifyObservers( light);
  }
}