// AmpelView2.java                              MM 2007
// MVC-View

import java.awt.*;                         // Dimension
import javax.swing.*;        // JPanel, JButton, JFrame
import java.util.*;                       // Observable
import Tools.MVC.*;                        // SuperView

/**
 * View zur Ampelschaltung,
 * Version mit Benutzeroberflaeche und MVC-Tool.
 */
public class AmpelView2
  extends SuperView
{
/* ------------------------------------------------- */
                                                 // GUI
/**
 * Konstante, Schalten der Ampel.
 */
  public static final String ACTION_SET = "Set";

/**
 * Konstante, Beenden des Programms.
 */
  public static final String ACTION_QUIT = "Quit";

/**
 * Darstellungsfenster.
 */
  private JFrame frame;

/**
 * Darstellungsbereich fuer GUI.
 */
  private JPanel contentPane;

/**
 * Ampelschalter Setzen.
 */
  private JButton btSet;

/**
 * Ampelschalter Abbruch.
 */
  private JButton btQuit;

/* ------------------------------------------------- */
                                    // MVC-Installation
/**
 * Konstruktor,
 * erzeugt Fenster mit Ueberschrift in Titelleiste
 * und installiert MVC.
 * @param model Ampel
 * @param titel Ueberschrift
 */
  public AmpelView2( AmpelModel model, String titel)
  {
// Fenster mit Titelzeile
    frame = new JFrame( titel);
// MVC-Installation
    initialize( model);
  }

/**
 * Erzeugt Controller,
 * ueberschreibt abstrakte View-Methode.
 * @return Controller fuer View
 */
  protected SuperController makeController()
  {
    return new AmpelController2();
  }

/**
 * Erzeugt View,
 * ueberschreibt abstrakte View-Methode,
 * baut die grafische Oberflaeche auf,
 * Controller verarbeitet Fensterereignisse.
 */
  protected void makeView()
  {
// ContentPane
    frame.setContentPane( createContentPane());

// Fenster
    frame.addWindowListener
    (((AmpelController2)controller).getWindowCloser());
    frame.pack();
    frame.setVisible( true);
  }

/**
 * Erzeugt Darstellungsbereich mit Steuerbuttons
 * und Ampel,
 * Controller verarbeitet Buttonereignisse.
 */
  private JPanel createContentPane()
  {
    contentPane = new JPanel();

    JButton btSet = new JButton( ACTION_SET); // Button
    contentPane.add( btSet);
    btSet.addActionListener
    ((AmpelController2)controller);

    JButton btQuit = new JButton( ACTION_QUIT);
    contentPane.add( btQuit);
    btQuit.addActionListener
    ((AmpelController2)controller);

    contentPane.add
    ( new AmpelPanel((AmpelModel)model));      // Ampel

    contentPane.setPreferredSize             // Groesse
    ( new Dimension( 120, 240));

    return contentPane;
  }
/* ------------------------------------------------- */
                                        // draw-Methode
/**
 * Darstellung der Ampel einschliesslich Button,
 * ueberschreibt abstrakte View-Methode.
 */
  protected void draw()
  {
    contentPane.repaint();
  }

/* ------------------------------------------------- */
                                  // MVC-Deinstallation
/**
 * Entfernt Fenster, deinstalliert MVC,
 * ueberschreibt View-Methode.
 */
  public void release()
  {
// Fenster entfernen
    frame.dispose();
// MVC-Deinstallation
    super.release();
  }
}